local gui = require "gui"

local commonapi2_init = require "commonapi2.init"
local _syncdata = commonapi._syncdata
--print("commonapi_gamescript", commonapi)
local firstHandleEventHandled = false
local firstHandleGuiEventHandled = false
local firstUpdateEventHandled = false

local errorWindow

local savedata = {}

local secondaryui = require "commonapi2.ui2.secondaryui"

local function showCommonErrorMessage(msg)
	local tv = gui.textView_create("commonErrorMessage.textView", msg, 400)
	errorWindow = gui.window_create("commonErrorMessage.window", _("Tip"), tv)
	errorWindow:setIcon("ui/icons/windows/tip.tga")
	errorWindow:onClose(function()
		errorWindow = nil
	end)
end

local commonapi_gamescript = {}
_G["commonapi_gamescript"] = commonapi_gamescript;

function commonapi_gamescript.getLineData()
	local lineData = {}
	local lineIds = game.interface.getLines()
	for i = 1, #lineIds do
		local line = game.interface.getEntity(lineIds[i])
		if (line.stops ~= nil) then
			line.stops_data = {}
			for s = 1, #line.stops do
				line.stops_data[#line.stops_data+1] = game.interface.getEntity(line.stops[s])
			end
		end
		lineData[#lineData+1] = line
	end

	return lineData
end



local linesextradetails_sync =
	_syncdata.SyncObject:new(
	{
		key = "linesextradetails",
		data = {}
	}
)


local guisendscriptevent = false
function commonapi_gamescript.saveData()
	print("commonapi_gamescript.saveData()")
	savedata.lineextradetails = linesextradetails_sync:getData()
	guisendscriptevent = true
end





local initialized = false

function data()
--	print("commonapi_gamescript:data", commonapi)
	--local initialized = false

	local data = {
		init = function ()
			return savedata
		end,
		save = function ()
			return savedata
		end,
		load = function (state)
			if initialized then return end
			if state == nil or next(state) == nil then return end
			savedata = state

			if (linesextradetails_sync ~= nil) then
				if (state.lineextradetails ~= nil) then
					if (state.lineextradetails.version == 1) then
						print("Loading lineextradetails?")
						linesextradetails_sync:syncData(state.lineextradetails)
						if (commonapi._native ~= nil and commonapi._native.LabelSystem ~= nil) then
							commonapi._native.LabelSystem.updateData(linesextradetails_sync:getData())
						end
					end
				end
			end

			initialized = true
		end,
		update = function ()
			if firstUpdateEventHandled then return end
			if (commonapi._native ~= nil and commonapi._native.renameLuaState ~= nil) then
				commonapi._native.renameLuaState("Script Thread")
			end
			--savedata.lineextradetails = linesextradetails_sync:getData()
			firstUpdateEventHandled = true
		end,
		handleEvent = function (src, id, name, param)
			if (id == "__commonapi2savedata__") then
				print("__commonapi2savedata__ called")
				savedata = param
				return
			end
			if firstHandleEventHandled then return end
			--print("commonapi_gamescript:handleEvent", id, name)
			--commonapi._unique_threadid_check()
			if (commonapi._native ~= nil and commonapi._native.renameLuaState ~= nil) then
				commonapi._native.renameLuaState("Script Thread")
			end
			firstHandleEventHandled = true
		end,

		guiUpdate = function()
			if (guisendscriptevent == true) then
				print("guiUpdate() sending __commonapi2savedata__")
				guisendscriptevent = false
				game.interface.sendScriptEvent("__commonapi2savedata__", "", savedata)
			end
			if (secondaryui ~= nil) then
				if (secondaryui.isInit ~= true) then
					secondaryui.init()
				end
			end
		end,

		guiHandleEvent = function (id, name, param)
--			if (id == "__commonErrorMsg__") then
--				print("showErrorMessage in guiHandleEvent")
--				if (name == "showErrorMsg") then
--					showCommonErrorMessage(param.msg or "?")
--				end
--				return
--			end
			if firstHandleGuiEventHandled then return end
			--print("commonapi_gamescript:guiHandleEvent", id, name)
			--commonapi._unique_threadid_check()
			if (commonapi._native ~= nil and commonapi._native.renameLuaState ~= nil) then
				commonapi._native.renameLuaState("GUI Thread")
			end
			firstHandleGuiEventHandled = true
		end,
	}
return data
end